@@ -14,8 +14,6 @@
 #include <QByteArray>
 #include <QStringList>
 
-# if QT_VERSION_MAJOR == 6
-
 struct BrowserArgumentsPrivate;
 
 /**
@@ -152,9 +150,4 @@ private:
     BrowserArgumentsPrivate *d;
 };
 
-#else
-#include <KParts/BrowserArguments>
-using BrowserArguments = KParts::BrowserArguments;
-#endif
-
 #endif
