@@ -33,6 +33,12 @@ public:
     void load() override;
     void defaults() override;
 
+private:
+    /**
+     * @brief Calls setNeedsSave according to the status of the two submodules
+     */
+    void updateNeedsSave();
+
 private:
     QTabWidget *tab;
     KCookiesPolicies *policies;
